## 实时成交数据(爬虫版)

接口：realtime_tick，由于采集和拼接当日以来的成交全历史，因此接口提取数据时需要一定时间，请耐心等待。请将tushare升级到1.3.3版本以上。

描述：本接口是tushare org版实时接口的顺延，数据来自网络，且不进入tushare服务器，属于爬虫接口，数据包括该股票当日开盘以来的所有分笔成交数据。

权限：0积分完全开放，但需要有tushare账号，如果没有账号请先注册。

说明：由于该接口是纯爬虫程序，跟tushare服务器无关，因此tushare不对数据内容和质量负责。数据主要用于研究和学习使用，如做商业目的，请自行解决合规问题。

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码，需按tushare股票代码标准输入，比如：000001.SZ表示平安银行，600000.SH表示浦发银行，单次只能输入一个股票 |
| src | str | N | 数据源 （sina-新浪 dc-东方财富，默认sina） |

输出参数

| 名称 | 类型 | 描述 |
| --- | --- | --- |
| time | str | 交易时间 |
| price | float | 现价 |
| change | float | 价格变动 |
| volume | int | 成交量（单位：手） |
| amount | int | 成交金额（元） |
| type | str | 类型：买入/卖出/中性 |

接口用法

```python
import tushare as ts

#设置你的token，登录tushare在个人用户中心里拷贝
ts.set_token('你的token')

#sina数据
df = ts.realtime_tick(ts_code='600000.SH')


#东财数据
df = ts.realtime_tick(ts_code='600000.SH', src='dc')
```

数据样例

```python
TIME      PRICE  CHANGE  VOLUME   AMOUNT TYPE
0     09:25:01   6.57   -0.01     429   281853   卖盘
```